@@ -13,16 +13,16 @@ class DictionaryRunner : public Plasma::AbstractRunner
     Q_OBJECT
 
 public:
-    DictionaryRunner(QObject *parent, const QVariantList &args);
-    void match(Plasma::RunnerContext &context) Q_DECL_OVERRIDE;
-    void reloadConfiguration() Q_DECL_OVERRIDE;
+    explicit DictionaryRunner(QObject *parent, const QVariantList &args);
+    void match(Plasma::RunnerContext &context) override;
+    void reloadConfiguration() override;
 
 private:
     QString m_triggerWord;
     DictionaryMatchEngine *m_engine;
 
-protected slots:
-    void init() Q_DECL_OVERRIDE;
+protected Q_SLOTS:
+    void init() override;
 
 };
 
